@@ -1,20 +1,15 @@
 import unittest
 import doctest
 
-from zope.testing import doctestunit
-from zope.component import testing, eventtesting
-
-from Testing import ZopeTestCase as ztc
-
-from quintagroup.seoptimizer.tests import base
+from base import *
 
 def test_suite():
     return unittest.TestSuite([
 
         # Demonstrate the main content types
-        ztc.ZopeDocFileSuite(
-            'browser.txt', package='quintagroup.seoptimizer',
-            test_class=base.FunctionalTestCase,
+        ztc.FunctionalDocFileSuite(
+            'browser.txt', package='quintagroup.seoptimizer.tests',
+            test_class=FunctionalTestCaseNotInstalled, globs=globals(),
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE |
                 doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),
 
